@@ -12,19 +12,12 @@ class MappingBuilder(JSONBaseBuilder):
     output_file_name = "mapping-file"
     parent_module_root_name = "mappings"
 
-    @process("/model/**", condition=lambda current, stack: stack.schema_valid)
+    @process("**", condition=lambda current, stack: stack.schema_valid)
     def enter_model_element(self):
         # ignore schema leaves different than "type" - for example, minLength, ...
         # that should not be present in mapping
-        if (
-            self.stack.top_type in (self.stack.LIST, self.stack.DICT)
-            or
-            # ignore top-level type=object as it is not allowed
-            # in elasticsearch mapping
-            self.stack.level > 3
-            and self.stack.top.key == "type"
-        ):
-            element_type = self.stack.top.schema_element_type
+        element_type = self.stack.top.schema_element_type
+        if element_type in ("properties", "property", "type", "items"):
             if element_type == "items":
                 # do not output "items" container
                 self.build_children()
@@ -44,13 +37,27 @@ class MappingBuilder(JSONBaseBuilder):
             self.model_element_leave()
 
     def merge_mapping(self, data):
-        if isinstance(data, dict) and "oarepo:mapping" in data:
-            mapping = self.call_components("before_merge_mapping", data["oarepo:mapping"], stack=self.stack)
+        if isinstance(data, dict) and "mapping" in data:
+            mapping = self.call_components(
+                "before_merge_mapping", data["mapping"], stack=self.stack
+            )
             self.output.merge_mapping(mapping)
 
     def on_enter_model(self, output_name):
-        ensure_parent_modules(self.builder, Path(output_name), ends_at=self.parent_module_root_name)
-        self.output.merge(self.settings.elasticsearch.templates[self.settings.elasticsearch.version])
+        ensure_parent_modules(
+            self.builder, Path(output_name), ends_at=self.parent_module_root_name
+        )
+        if "mapping" in self.current_model:
+            if (
+                "opensearch" not in self.settings
+                or "version" not in self.settings.opensearch
+            ):
+                raise ValueError(
+                    "Please define settings.opensearch.version (for example, to os-v2)"
+                )
+            self.output.merge(
+                self.current_model.mapping[self.settings.opensearch.version]
+            )
         self.output.enter("mappings", {})
 
     def finish(self):
