@@ -2,10 +2,12 @@ from oarepo_model_builder.builders import process
 from oarepo_model_builder.utils.jinja import package_name
 
 from ..outputs.json_stack import JSONStack
+from ..utils.deepmerge import deepmerge
 from ..utils.hyphen_munch import HyphenMunch
 from .invenio_base import InvenioBaseClassPythonBuilder
 
-OAREPO_FACETS_PROPERTY = "oarepo:facets"
+OAREPO_FACETS_PROPERTY = "facets"
+OAREPO_SORTABLE_PROPERTY = "sortable"
 
 
 class InvenioRecordSearchOptionsBuilder(InvenioBaseClassPythonBuilder):
@@ -17,23 +19,40 @@ class InvenioRecordSearchOptionsBuilder(InvenioBaseClassPythonBuilder):
         super().begin(schema, settings)
         self.template = "record-search-options"
         self.search_options_data = []
+        self.sort_options_data = []
         self.search_facets_definiton = []
         self.search_options_stack = JSONStack()
         self.facets_definition = []
         self.facets_names = []
+        self.settings = settings
+        if "sortable" in schema.schema:
+            self.process_top_sortable(schema.schema["sortable"])
 
     def finish(self, **extra_kwargs):
-        super().finish(search_options_data=self.search_options_data, facets_definition=self.facets_definition)
-        python_path = self.class_to_path(self.settings.python["record-facets-class"])
+        super().finish(
+            search_options_data=self.search_options_data,
+            facets_definition=self.facets_definition,
+            sort_definition=self.sort_options_data,
+        )
+        python_path = self.class_to_path(self.current_model.record_facets_class)
         self.process_template(
             python_path,
             "record-facets",
-            current_package_name=package_name(self.settings.python["record-facets-class"]),
+            current_package_name=package_name(self.current_model.record_facets_class),
             search_options_data=self.search_options_data,
             **extra_kwargs,
         )
 
-    @process("/model/**", condition=lambda current, stack: stack.schema_valid)
+    def process_top_sortable(self, data):
+        keys = dir(data)
+        for k in keys:
+            fields = dir(data[k])
+            fields_options = {}
+            for field in fields:
+                fields_options = deepmerge(fields_options, {field: data[k][field]})
+            self.sort_options_data.append({k: fields_options})
+
+    @process("**", condition=lambda current, stack: stack.schema_valid)
     def enter_model_element(self):
         schema_element_type = self.stack.top.schema_element_type
 
@@ -49,29 +68,47 @@ class InvenioRecordSearchOptionsBuilder(InvenioBaseClassPythonBuilder):
         if not self.search_options_stack:
             return
 
+        if schema_element_type == "property":
+            sort_definition = data.get(OAREPO_SORTABLE_PROPERTY, None)
+
+            if sort_definition != None:
+                self.sort_options_data.append(
+                    self.process_sort_options(self.stack.path, sort_definition)
+                )
+        array_items_type = None
+        if schema_element_type == "property" and data.type == "array":
+            try:
+                array_items_type = data["items"]["type"]
+            except:
+                array_items_type = None
+
         if (
             schema_element_type == "property"
             and data.type != "text"
             and data.type != "fulltext"
             and data.type != "object"
             and data.type != "nested"
+            and not (data.type == "array" and array_items_type == "fulltext")
         ):
             definition = data.get(OAREPO_FACETS_PROPERTY, {})
             nested_paths = []
             nested_path = ""
             nested = False
-            path_stack = self.stack.stack[3:]  # start inside model properties
+            path_stack = self.stack.stack[2:]  # start inside model properties
             for upper in path_stack:
                 if upper.key == "properties":
                     continue
                 nested_path = nested_path + upper.key + "."
-                if upper.data.get("oarepo:mapping", HyphenMunch({"type": ""})).type == "nested":
+                if upper.data.get("mapping", {"type": ""}).get("type") == "nested":
                     nested_paths.append(nested_path)
             if len(nested_paths) > 0:
                 nested = True
 
-            name = self.process_name(self.stack.path, type="name")
-            if data.type == "fulltext+keyword":
+            if "key" in definition:
+                name = definition["key"]
+            else:
+                name = self.process_name(self.stack.path, type="name")
+            if data.type == "fulltext+keyword" and "key" not in definition:
                 name = name + "_keyword"
             if name == "$schema":
                 name = "_schema"
@@ -86,7 +123,12 @@ class InvenioRecordSearchOptionsBuilder(InvenioBaseClassPythonBuilder):
                         class_string = class_string + "path = " + '"' + path[:-1] + '"'
                     else:
                         class_string = (
-                            class_string + "path = " + '"' + path[:-1] + '"' + ", nested_facet = NestedLabeledFacet("
+                            class_string
+                            + "path = "
+                            + '"'
+                            + path[:-1]
+                            + '"'
+                            + ", nested_facet = NestedLabeledFacet("
                         )
 
             if "field" in definition:
@@ -109,13 +151,17 @@ class InvenioRecordSearchOptionsBuilder(InvenioBaseClassPythonBuilder):
                     if "class" != key and "field" != key:
                         search_data.append([key, value])
                 if nested:
-                    search_options = self.process_search_options(search_data, facets_class)
+                    search_options = self.process_search_options(
+                        search_data, facets_class
+                    )
                     search_options = class_string + " , nested_facet =" + search_options
                     for x in nested_paths:
                         search_options = search_options + ")"
 
                 else:
-                    search_options = self.process_search_options(search_data, facets_class)
+                    search_options = self.process_search_options(
+                        search_data, facets_class
+                    )
                 self.search_options_data.append({name: search_options})
             facets_name = "facets." + name
             self.facets_definition.append({name: facets_name})
@@ -130,13 +176,16 @@ class InvenioRecordSearchOptionsBuilder(InvenioBaseClassPythonBuilder):
         return field_class + "(" + text + ")"
 
     def process_name(self, path, type):
-        path_array = (path.split("/"))[3:]
+        path_array = (path.split("/"))[2:]
         name = path_array[0]
         if len(path_array) == 1:
             return name
         path_array.pop(0)
-
+        last_path = ""
         for path in path_array:
+            if last_path != "properties" and path == "items":
+                continue
+            last_path = path
             if path == "properties":
                 continue
             if type == "name":
@@ -145,3 +194,15 @@ class InvenioRecordSearchOptionsBuilder(InvenioBaseClassPythonBuilder):
                 name = name + "." + path
 
         return name
+
+    def process_sort_options(self, path, definition):
+        field = self.process_name(path=path, type="field")
+
+        key = definition.get("key", "")
+        if key == "":
+            key = self.process_name(path, "name")
+        order = definition.get("order", "asc")
+        if order == "desc":
+            field = "-" + field
+
+        return {key: dict(fields=[field])}
