@@ -1,8 +1,8 @@
 import marshmallow as ma
 from marshmallow import fields
-from .model_validation import model_validator
 
-from .utils import ExtendablePartSchema, CheckedConstant, PermissiveSchema
+from .model_validation import model_validator
+from .utils import CheckedConstant, ExtendablePartSchema, PermissiveSchema
 
 
 class ModelSchema(ExtendablePartSchema):
@@ -14,8 +14,8 @@ class ModelSchema(ExtendablePartSchema):
         lambda: model_validator.validator_class("model-opensearch", strict=False)()
     )
     plugins = fields.Nested(
-            lambda: model_validator.validator_class("plugins-schema")(), required=False
-        )
+        lambda: model_validator.validator_class("plugins-schema")(), required=False
+    )
 
     @ma.pre_load(pass_many=False)
     def set_properties_before_load(self, data, **kwargs):
