@@ -1,6 +1,7 @@
 import os
 
-from oarepo_model_builder.entrypoints import create_builder_from_entrypoints, load_model
+from oarepo_model_builder.entrypoints import (create_builder_from_entrypoints,
+                                              load_model)
 from oarepo_model_builder.fs import InMemoryFileSystem
 
 
