@@ -6,9 +6,9 @@ import sys
 from pathlib import Path
 from tempfile import mkdtemp, tempdir
 
-from oarepo_model_builder.entrypoints import create_builder_from_entrypoints, load_model
-from oarepo_model_builder.fs import FileSystem
-from oarepo_model_builder.fs import InMemoryFileSystem
+from oarepo_model_builder.entrypoints import (create_builder_from_entrypoints,
+                                              load_model)
+from oarepo_model_builder.fs import FileSystem, InMemoryFileSystem
 from tests.utils import assert_python_equals
 
 OAREPO_USE = "use"
